@@ -2,6 +2,7 @@ package api
 
 import (
 	"fmt"
+	"time"
 
 	"github.com/xanzy/go-gitlab"
 )
@@ -57,3 +58,21 @@ var UsersByNames = func(client *gitlab.Client, names []string) ([]*gitlab.User,
 	}
 	return users, nil
 }
+
+var CreatePersonalAccessTokenForCurrentUser = func(client *gitlab.Client, name string, scopes []string, expiresAt time.Time) (*gitlab.PersonalAccessToken, error) {
+	if client == nil {
+		client = apiClient.Lab()
+	}
+	expiresAtISO := gitlab.ISOTime(expiresAt)
+	options := &gitlab.CreatePersonalAccessTokenForCurrentUserOptions{
+		Name:      gitlab.String(name),
+		Scopes:    &scopes,
+		ExpiresAt: &expiresAtISO,
+	}
+
+	pat, _, err := client.Users.CreatePersonalAccessTokenForCurrentUser(options)
+	if err != nil {
+		return nil, err
+	}
+	return pat, nil
+}
